# Calculator_Math_Operations

Este é um pacote Python que fornece funções para realizar operações matemáticas básicas, como soma e subtração.

## Instalação

```bash
pip install calculator_math_operations_package
```

## Uso

```python
from calculator_math_operations import addition, subtraction

print(addition.add(2, 3))  # Saída: 5
print(subtraction.subtract(5, 2))  # Saída: 3
```

## Autor

[LuthLucas](https://github.com/LuthLucas)